==> haskell-presburger-1.3.1-14-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-presburger.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 presburger
version:              1.3.1
visibility:           public
id:                   presburger-1.3.1-GdVZ5DvjhBWIM1NeWtJZHq
key:                  presburger-1.3.1-GdVZ5DvjhBWIM1NeWtJZHq
license:              BSD-3-Clause
maintainer:           diatchki@galois.com
author:               Iavor S. Diatchki
homepage:             http://github.com/yav/presburger
synopsis:             A decision procedure for quantifier-free linear arithmetic.
description:
    The decision procedure is based on the algorithm used in
    CVC4, which is itself based on the Omega test.

category:             Algorithms
abi:                  d2a9f31ab6fdae220ccfe68ab3439b12
exposed:              True
exposed-modules:      Data.Integer.SAT
import-dirs:          /usr/lib/ghc-8.10.1/site-local/presburger-1.3.1
library-dirs:         /usr/lib/ghc-8.10.1/site-local/presburger-1.3.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.1/presburger-1.3.1
hs-libraries:         HSpresburger-1.3.1-GdVZ5DvjhBWIM1NeWtJZHq
depends:              base-4.14.0.0 containers-0.6.2.1 pretty-1.1.3.6
haddock-interfaces:   /usr/share/doc/haskell-presburger/html/presburger.haddock
haddock-html:         /usr/share/doc/haskell-presburger/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-presburger-1.3.1-15-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-presburger.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 presburger
version:              1.3.1
visibility:           public
id:                   presburger-1.3.1-55WKUXeptl6HWqASaWDStD
key:                  presburger-1.3.1-55WKUXeptl6HWqASaWDStD
license:              BSD-3-Clause
maintainer:           diatchki@galois.com
author:               Iavor S. Diatchki
homepage:             http://github.com/yav/presburger
synopsis:             A decision procedure for quantifier-free linear arithmetic.
description:
    The decision procedure is based on the algorithm used in
    CVC4, which is itself based on the Omega test.

category:             Algorithms
abi:                  3fa3a2e2383f234bf594af15feb959fd
exposed:              True
exposed-modules:      Data.Integer.SAT
import-dirs:          /usr/lib/ghc-8.10.2/site-local/presburger-1.3.1
library-dirs:         /usr/lib/ghc-8.10.2/site-local/presburger-1.3.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.2/presburger-1.3.1
hs-libraries:         HSpresburger-1.3.1-55WKUXeptl6HWqASaWDStD
depends:              base-4.14.1.0 containers-0.6.2.1 pretty-1.1.3.6
haddock-interfaces:   /usr/share/doc/haskell-presburger/html/presburger.haddock
haddock-html:         /usr/share/doc/haskell-presburger/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
